@@ -8,17 +8,18 @@ import (
 	"github.com/wader/fq/pkg/interp"
 )
 
-var imageFormat decode.Group
+var imageGroup decode.Group
 
 func init() {
-	interp.RegisterFormat(decode.Format{
-		Name:        format.APEV2,
-		Description: "APEv2 metadata tag",
-		DecodeFn:    apev2Decode,
-		Dependencies: []decode.Dependency{
-			{Names: []string{format.IMAGE}, Group: &imageFormat},
-		},
-	})
+	interp.RegisterFormat(
+		format.Apev2,
+		&decode.Format{
+			Description: "APEv2 metadata tag",
+			DecodeFn:    apev2Decode,
+			Dependencies: []decode.Dependency{
+				{Groups: []*decode.Group{format.Image}, Out: &imageGroup},
+			},
+		})
 }
 
 func apev2Decode(d *decode.D) any {
@@ -59,7 +60,7 @@ func apev2Decode(d *decode.D) any {
 					d.FramedFn(int64(itemSize)*8, func(d *decode.D) {
 						d.FieldUTF8Null("filename")
 						// assume image if binary
-						d.FieldFormatOrRaw("value", imageFormat, nil)
+						d.FieldFormatOrRaw("value", &imageGroup, nil)
 					})
 				} else {
 					d.FieldUTF8("value", int(itemSize))
