@@ -369,21 +369,22 @@ func machoDecode(d *decode.D) any {
 	var ncmds uint64
 	magicBuffer := d.U32LE()
 
-	if magicBuffer == MH_MAGIC || magicBuffer == MH_MAGIC_64 {
+	switch magicBuffer {
+	case MH_MAGIC, MH_MAGIC_64:
 		d.Endian = decode.LittleEndian
 		if magicBuffer == MH_MAGIC {
 			archBits = 32
 		} else {
 			archBits = 64
 		}
-	} else if magicBuffer == MH_CIGAM || magicBuffer == MH_CIGAM_64 {
+	case MH_CIGAM, MH_CIGAM_64:
 		d.Endian = decode.BigEndian
 		if magicBuffer == MH_CIGAM {
 			archBits = 32
 		} else {
 			archBits = 64
 		}
-	} else {
+	default:
 		d.Fatalf("invalid magic")
 	}
 
@@ -623,7 +624,7 @@ func machoDecode(d *decode.D) any {
 
 					d.SeekAbs(int64(symOff) * 8)
 					d.FieldArray("symbols", func(d *decode.D) {
-						for i := 0; i < int(nSyms); i++ {
+						for range int(nSyms) {
 							symbolTypeMap := scalar.UintMapSymStr{
 								0x0: "undef",
 								0x1: "abs",
