@@ -38,7 +38,7 @@ var fitCRCTable = [16]uint16{
 func calcCRC(bytes []byte) uint16 {
 	var crc uint16
 	crc = 0
-	for i := 0; i < len(bytes); i++ {
+	for i := range bytes {
 		// compute checksum of lower four bits of byte
 		var checkByte = bytes[i]
 		var tmp = fitCRCTable[crc&0xf]
@@ -401,9 +401,9 @@ func decodeFIT(d *decode.D) any {
 	var fc fitContext
 	d.Endian = decode.LittleEndian
 
-	var lmfd localFieldDefMap = make(localFieldDefMap)
-	var dmfd devFieldDefMap = make(devFieldDefMap)
-	var isDevMap localMsgIsDevDef = make(localMsgIsDevDef)
+	lmfd := make(localFieldDefMap)
+	dmfd := make(devFieldDefMap)
+	isDevMap := make(localMsgIsDevDef)
 
 	d.FieldStruct("header", func(d *decode.D) { fitDecodeFileHeader(d, &fc) })
 
