@@ -165,6 +165,7 @@ var (
 	ProtobufWidevine    = &decode.Group{Name: "protobuf_widevine"}
 	PSSH_Playready      = &decode.Group{Name: "pssh_playready"}
 	RTMP                = &decode.Group{Name: "rtmp"}
+	SAFETENSORS         = &decode.Group{Name: "safetensors"}
 	SLL_Packet          = &decode.Group{Name: "sll_packet"}
 	SLL2_Packet         = &decode.Group{Name: "sll2_packet"}
 	TAP                 = &decode.Group{Name: "tap"}
@@ -197,10 +198,46 @@ type AAC_Frame_In struct {
 }
 type AVC_AU_In struct {
 	LengthSize uint64 `doc:"Length value size"`
+	AVC_SPS_Info
+	AVC_PPS_Info
+}
+
+type AVC_NALU_In struct {
+	AVC_SPS_Info
+	AVC_PPS_Info
+}
+
+type AVC_NALU_Out struct {
+	AVC_SPS_Info
+	AVC_PPS_Info
 }
 
 type AVC_DCR_Out struct {
 	LengthSize uint64
+	AVC_SPS_Info
+	AVC_PPS_Info
+}
+
+type AVC_PPS_Info struct {
+	BottomFieldPicOrderInFramePresentFlag bool `doc:""`
+	RedundantPicCntPresentFlag            bool `doc:""`
+}
+
+type AVC_PPS_Out struct {
+	AVC_PPS_Info
+}
+
+type AVC_SPS_Info struct {
+	SeparateColourPlaneFlag     bool   `doc:""`
+	Log2MaxFrameNum             uint64 `doc:""`
+	FrameMbsOnlyFlag            bool   `doc:""`
+	PicOrderCntType             uint64 `doc:""`
+	Log2MaxPicOrderCntLsb       uint64 `doc:""`
+	DeltaPicOrderAlwaysZeroFlag bool   `doc:""`
+}
+
+type AVC_SPS_Out struct {
+	AVC_SPS_Info
 }
 
 type CAFF_In struct {
@@ -209,7 +246,8 @@ type CAFF_In struct {
 
 type FLAC_Frame_In struct {
 	SamplesBuf    []byte
-	BitsPerSample int `doc:"Bits per sample"`
+	BitsPerSample int  `doc:"Bits per sample"`
+	SampleDetails bool `doc:"Decode more sample details like residuals etc"`
 }
 
 type FLAC_Frame_Out struct {
