@@ -86,9 +86,7 @@ func (i *Interp) _registry(c any) any {
 		}
 		if f.DefaultInArg != nil {
 			doc := map[string]any{}
-			st := reflect.TypeOf(f.DefaultInArg)
-			for i := range st.NumField() {
-				f := st.Field(i)
+			for _, f := range mapstruct.StructFieldsSquashed(f.DefaultInArg) {
 				if v, ok := f.Tag.Lookup("doc"); ok {
 					doc[mapstruct.CamelToSnake(f.Name)] = v
 				}
@@ -205,8 +203,8 @@ func (i *Interp) _decode(c any, format string, opts decodeOpts) any {
 				lastProgress = n
 				evalProgress(
 					map[string]any{
-						"approx_read_bytes": approxReadBytes,
-						"total_size":        totalSize,
+						"approx_read_bytes": float64(approxReadBytes),
+						"total_size":        float64(totalSize),
 					},
 				)
 			}
